==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TemplateCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TemplateCellInfoDescription } from "./TemplateCellInfoDescription";
/**
 * @hidden
 */
var TemplateCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateCellInfoDescriptionMetadata, _super);
    function TemplateCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateCellInfoDescriptionMetadata.b = function (a) {
        if (TemplateCellInfoDescriptionMetadata.a == null) {
            TemplateCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateCellInfoDescriptionMetadata.c(TemplateCellInfoDescriptionMetadata.a);
        }
        if (a.g(TemplateCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(TemplateCellInfoDescriptionMetadata.a);
    };
    TemplateCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
    };
    TemplateCellInfoDescriptionMetadata.d = function (a) {
        TemplateCellInfoDescriptionMetadata.b(a);
        a.u("TemplateCellInfo", function () { return new TemplateCellInfoDescription(); });
        a.t("TemplateCellInfo", TemplateCellInfoDescriptionMetadata.a);
    };
    TemplateCellInfoDescriptionMetadata.$t = markType(TemplateCellInfoDescriptionMetadata, 'TemplateCellInfoDescriptionMetadata');
    TemplateCellInfoDescriptionMetadata.a = null;
    return TemplateCellInfoDescriptionMetadata;
}(Base));
export { TemplateCellInfoDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TemplateCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TemplateCellInfoDescription } from "./TemplateCellInfoDescription";
/**
 * @hidden
 */
var TemplateCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateCellInfoDescriptionMetadata, _super);
    function TemplateCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateCellInfoDescriptionMetadata.b = function (a) {
        if (TemplateCellInfoDescriptionMetadata.a == null) {
            TemplateCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateCellInfoDescriptionMetadata.c(TemplateCellInfoDescriptionMetadata.a);
        }
        if (a.j(TemplateCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateCellInfoDescriptionMetadata.a);
    };
    TemplateCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
    };
    TemplateCellInfoDescriptionMetadata.d = function (a) {
        TemplateCellInfoDescriptionMetadata.b(a);
        a.aa("TemplateCellInfo", function () { return new TemplateCellInfoDescription(); });
        a.z("TemplateCellInfo", TemplateCellInfoDescriptionMetadata.a);
    };
    TemplateCellInfoDescriptionMetadata.$t = markType(TemplateCellInfoDescriptionMetadata, 'TemplateCellInfoDescriptionMetadata');
    TemplateCellInfoDescriptionMetadata.a = null;
    return TemplateCellInfoDescriptionMetadata;
}(Base));
export { TemplateCellInfoDescriptionMetadata };
